//
//  BPXLFile.m
//  CocoaHeads Sandbox
//
//  Created by Rick Fillion on 2013-03-11.
//  Copyright (c) 2013 Black Pixel. All rights reserved.
//

#import "BPXLFile.h"

static NSString *BPXLFileBookmarkTestStatusWaiting = @"Waiting";
static NSString *BPXLFileBookmarkTestStatusPassed = @"Passed";
static NSString *BPXLFileBookmarkTestStatusFailed = @"Failed";
static NSString *BPXLFileBookmarkTestStatusError = @"Unknown Error";

@interface BPXLFile ()

@property (nonatomic, strong) NSURL *URL;
@property (nonatomic, strong) NSString *bookmarkTestStatus;
@property (nonatomic, strong) NSURL *resolvedSecurityScopedBookmarkURL;

@end

@implementation BPXLFile

+ (instancetype)fileWithURL:(NSURL *)aURL
{
	return [[self alloc] initWithURL:aURL];
}

- (instancetype)initWithURL:(NSURL *)aURL
{
	if (self = [super init])
	{
		self.URL = aURL;
		self.bookmarkTestStatus = BPXLFileBookmarkTestStatusWaiting;
	}
	return self;
}

- (NSString *)path
{
	return [self.URL path];
}

- (void)runBookmarkTest
{
	NSLog(@"Running test for: %@", [self path]);

	[self bpxl_createAndResolveBookmark];
	
	if (self.resolvedSecurityScopedBookmarkURL == nil)
	{
		// If we were unable to even create a bookmark, bad things happened.
		self.bookmarkTestStatus = BPXLFileBookmarkTestStatusError;
	}
	else if ([[self.resolvedSecurityScopedBookmarkURL path] isEqualToString:[self path]])
	{
		self.bookmarkTestStatus = BPXLFileBookmarkTestStatusPassed;
	}
	else
	{
		self.bookmarkTestStatus = BPXLFileBookmarkTestStatusFailed;
		NSLog(@"Found failure:\n\t%@\n\t%@", [self path], [self.resolvedSecurityScopedBookmarkURL path]);
	}
}

- (void)bpxl_createAndResolveBookmark
{
	self.resolvedSecurityScopedBookmarkURL = nil;
	
    NSInteger bookmarkCreationOptions = NSURLBookmarkCreationWithSecurityScope;
	NSInteger bookmarkResolutionOptions = NSURLBookmarkResolutionWithSecurityScope;
	
    NSData *bookmarkData = [self.URL bookmarkDataWithOptions:bookmarkCreationOptions includingResourceValuesForKeys:nil relativeToURL:nil error:NULL];
	NSURL *bookmarkURL = [NSURL URLByResolvingBookmarkData:bookmarkData options:bookmarkResolutionOptions relativeToURL:nil bookmarkDataIsStale:NULL error:NULL];
	
	self.resolvedSecurityScopedBookmarkURL = bookmarkURL;
}

@end
